//{{NO_DEPENDENCIES}}

//  Usage
#define IDS_USAGE                       5000
#define IDS_INVALIDCOMMANDLINE          5001

// Window state
#define IDS_ALWAYSONTOP                 5010

// Status bar
#define IDS_READ_ONLY                   5028
#define IDS_BLANK                       5029
#define IDS_READ_WRITE                  5033

// File Dialog filters
#define IDS_FDF_V3_ALL                  5050
#define IDS_FDF_DB_ALL                  5051
#define IDS_FDF_DB_BU_ALL               5052
#define IDS_FDF_T_C_ALL                 5053
#define IDS_FDF_X_ALL                   5054
#define IDS_FDF_XML                     5055
#define IDS_FDF_BU                      5056
#define IDS_FDF_BUS                     5057
#define IDS_FDF_PR_ALL                  5058
#define IDS_FDF_TXT_ALL                 5059
#define IDS_FDF_CSV_ALL                 5060
#define IDS_FDF_V12_ALL                 5061
#define IDS_FDF_V4_ALL                  5062
#define IDS_FDF_ALL                     5063
#define IDS_FDF_FILES                   5064

// Tooltips
#define IDS_RESETPWHISTORYOFF           5100
#define IDS_RESETPWHISTORYON            5101
#define IDS_SETMAXPWHISTORY             5102
#define IDS_REGDEL                      5103
#define IDS_BACKUPBEFORESAVE            5104
#define IDS_USERBACKUPOTHERLOCATION     5106
#define IDS_MAINTAINDATETIMESTAMPS      5107
#define IDS_OTHERBROWSERLOCATION        5108
#define IDS_OTHEREDITORLOCATION         5109
#define IDS_MIGRATETOAPPDATA            5110
#define IDS_CLEARPWHISTORY              5111
#define IDS_SAVEIMMEDIATELY             5112
#define IDS_DBLOCK                      5113
#define IDS_USERBACKUPOTHERLOCATION2    5114
#define IDS_SMARTLABELHELP              5115
#define IDS_PASSWORDHELP                5116
#define IDS_NOTESHELP                   5117
#define IDS_AUTOTYPEHELP                5118
#define IDS_PWHHELP                     5119
#define IDS_PASSWORDHELP2               5120
#define IDS_TRANSPARENCYHELP            5121
#define IDS_EXCLUDE_FROM_SCR_CAP_HELP   5122
#define IDS_PWSTRNGTH_WEAK              5123
#define IDS_PWSTRNGTH_MEDIUM            5124
#define IDS_PWSTRNGTH_STRONG            5125

// Program strings
#define IDS_FILEERROR1                  5210
#define IDS_FILEERROR2                  5211
#define IDS_ERRORMESSAGE                5212
#define IDS_FILEREADONLY                5213
#define IDS_FILEPATHNOTFOUND            5214
#define IDS_TERMINATE                   5215
#define IDS_RECENT                      5216
#define IDS_RECENTSAFES                 5217
#define IDS_OPTIONS                     5218
#define IDS_ENCRYPTIONFAILED            5219
#define IDS_GROUPTITLE                  5220
#define IDS_GROUP                       5221
#define IDS_TITLE                       5222
#define IDS_USERNAME                    5223
#define IDS_PASSWORD                    5224
#define IDS_NOTES                       5225
#define IDS_URL                         5226
#define IDS_CREATED                     5227
#define IDS_PASSWORDMODIFIED            5228
#define IDS_LASTACCESSED                5229
#define IDS_PASSWORDEXPIRYDATE          5230
#define IDS_LASTMODIFIED                5232
#define IDS_COPYTITLE                   5233
#define IDS_PROCESSID                   5234
#define IDS_LOCKED                      5235
#define IDS_FILEINUSE                   5236
#define IDS_FILEOPEN                    5237
#define IDS_SAFENOTEXIST                5238
#define IDS_SAVECHANGES                 5239
#define IDS_NUMITEMS                    5240
#define IDS_NEVER                       5241
#define IDS_HIDDENNOTES                 5242
#define IDS_SHOWPASSWORDTXT             5245
#define IDS_HIDEPASSWORDTXT             5246
#define IDS_MUSTHAVETITLE               5247
#define IDS_MUSTHAVEPASSWORD            5248
#define IDS_DOTINVALID                  5249
#define IDS_PASSWORDSNOTMATCH           5250
#define IDS_ENTRYEXISTS                 5251
#define IDS_ENTRIESDONOTMATCH           5254
#define IDS_ENTERKEYANDVERIFY           5255
#define IDS_PASSWORDOVERRIDE            5256
#define IDS_LOCKSAFE                    5257
#define IDS_UNLOCKSAFE                  5258
#define IDS_NOSAFE                      5259
#define IDS_COPYURL                     5260
#define IDS_VIEWENTRY2                  5261
#define IDS_UNKNOWN                     5263
#define IDS_VIEWENTRY                   5264
#define IDS_ON                          5265
#define IDS_OFF                         5266
#define IDS_NEEDDELIMITER               5267
#define IDS_INVALIDDELIMITER            5268
#define IDS_NOFIELDSFOREXPORT           5269
#define IDS_NOOBJECT                    5270
#define IDS_NOFUNCTION                  5271
#define IDS_ENTERSEARCHSTRING           5272
#define IDS_NOMATCHFOUND                5273
#define IDS_FOUNDAMATCH                 5274
#define IDS_FOUNDMATCHES                5275
#define IDS_SEARCHWRAPPED               5276
#define IDS_IMPORTED                    5277
#define IDS_NOCURRENTSAFE               5278
#define IDS_CANNOTBEBLANK               5279
#define IDS_INCORRECTKEY                5280
#define IDS_WEAKPASSPHRASE              5281
#define IDS_USEITANYWAY                 5282
#define IDS_TRYANOTHER                  5283
#define IDS_WRONGOLDPHRASE              5284
#define IDS_CANTVERIFY                  5285
#define IDS_NEWOLDDONOTMATCH            5286
#define IDS_CONFIRMDELETEREG            5287
#define IDS_NOHOTKEY                    5288
#define IDS_INVALIDTIMEOUT              5289
#define IDS_HEXMUTUALLYEXCL             5290
#define IDS_HEXMUSTBEEVEN               5291
#define IDS_MUSTHAVEONEOPTION           5292
#define IDS_DEFAULTPWLENGTH             5293
#define IDS_DEFAULTNUMPWH               5294
#define IDS_SETDATETIME                 5295
#define IDS_TRAYAUTOTYPE                5296
#define IDS_TRAYBROWSE                  5297
#define IDS_TRAYCOPYNOTES               5298
#define IDS_TRAYCOPYPASSWORD            5299
#define IDS_TRAYCOPYUSERNAME            5300
#define IDS_TRAYVIEWEDIT                5301
#define IDS_TRAYDELETETRAYENTRY         5302
#define IDS_CANTPROCESSENTRY            5303
#define IDS_TRAYCOPYURL                 5304
#define IDS_SETUSERNAME                 5305
#define IDS_NEWGROUP                    5306
#define IDS_COPYNUMBER                  5307
#define IDS_COULDNOTSAVE                5308
#define IDS_SAVEERROR                   5309
#define IDS_CANTBROWSE                  5310
#define IDS_CANTOPENSAFE                5311
#define IDS_FILECORRUPT                 5312
#define IDS_FILEREADERROR               5313
#define IDS_SAVEDATABASE                5314
#define IDS_CHOOSEDATABASE              5315
#define IDS_ALREADYOPEN                 5316
#define IDS_OPENDATABASE                5317
#define IDS_CANTOPEN                    5318
#define IDS_FILEOPENERROR               5319
#define IDS_CANTOPENREADING             5320
#define IDS_UNKNOWNERROR                5321
#define IDS_CONFIRMOLDPHRASE            5322
#define IDS_NEWFORMAT2                  5323
#define IDS_VERSIONWARNING              5324
#define IDS_CANTOPENWRITING             5325
#define IDS_FILEWRITEERROR              5326
#define IDS_NEWNAME1                    5327
#define IDS_NEWNAME2                    5328
#define IDS_FILEISLOCKED                5329
#define IDS_FILELOCKERROR               5330
#define IDS_NAMEEXPORTFILE              5331
#define IDS_NAMETEXTFILE                5332
#define IDS_NAMEXMLFILE                 5333
#define IDS_BADPASSKEY                  5334
#define IDS_PICKTEXTFILE                5335
#define IDS_INVALIDFORMAT               5336
#define IDS_STATUS                      5337
#define IDS_RECORDSIMPORTED             5338
#define IDS_RECORDSSKIPPED              5339
#define IDS_PICKKEEPASSFILE             5340
#define IDS_PICKXMLFILE                 5343
#define IDS_FAILEDXMLVALIDATE           5344
#define IDS_XMLERRORS                   5345
#define IDS_XMLIMPORTWITHERRORS         5346
#define IDS_XMLIMPORTOK                 5347
#define IDS_PICKMERGEFILE               5348
#define IDS_MERGINGDATABASE             5350
#define IDS_NOCOMPAREFILE               5353
#define IDS_PICKCOMPAREFILE             5354
#define IDS_COMPARESAME                 5355
#define IDS_IDENTICALDATABASES          5357
#define IDS_COMPARECOMPLETE             5358
#define IDS_COMPAREENTRIES1             5360
#define IDS_COMPAREENTRIES2             5361
#define IDS_COMPAREBOTHDIFF             5362
#define IDS_COMPARESTATS2               5363
#define IDS_COMPPASSWORD                5364
#define IDS_COMPNOTES                   5365
#define IDS_COMPURL                     5366
#define IDS_COMPAUTOTYPE                5367
#define IDS_COMPCTIME                   5368
#define IDS_COMPPMTIME                  5369
#define IDS_COMPATIME                   5370
#define IDS_COMPXTIME                   5371
#define IDS_COMPRMTIME                  5372
#define IDS_COMPPWHISTORY               5373
#define IDS_SAVEFIRST                   5374
#define IDS_PICKBACKUP                  5375
#define IDS_PICKRESTORE                 5376
#define IDS_UNTITLEDRESTORE             5377
#define IDS_VALIDATE_OK                 5378
#define IDS_FAILEDSAVEPREF              5379
#define IDS_FAILEDSAVEPREFRO            5380
#define IDS_ENTRIESCHANGEDSTOP          5381
#define IDS_ENTRIESCHANGEDSAVE          5382
#define IDS_ENTRIESRESETMAX             5383
#define IDS_SELECTPROGRAM               5384
#define IDS_NOIBACKUP                   5385
#define IDS_NONE                        5386
#define IDS_INCREMENTNUM                5387
#define IDS_OPTBACKUPPREF               5388
#define IDS_OPTBACKUPSUBDIR             5389
#define IDS_OPTBACKUPLOCATION           5390
#define IDS_OPTBACKUPNOLOC              5391
#define IDS_OPTBACKUPMAXNUM             5392
#define IDS_OPTBACKUPTITLE              5393
#define IDS_DEFDBNAME                   5394
#define IDS_CREATENAME                  5395
#define IDS_COMPTWOFACTORKEY            5396
#define IDS_MENUEXPCOLGROUP             5400
#define IDS_MENUEDITENTRY               5401
#define IDS_MENUVIEWENTRY               5402
#define IDS_MENUDELETEGROUP             5404
#define IDS_MENURENAMEGROUP             5406
#define IDS_MAXNUMDAYSEXCEEDED          5407
#define IDS_HELPMENU                    5408
#define IDS_INVALIDEXPIRYWARNDAYS       5410
#define IDS_STRICT_LOCKED               5412
#define IDS_CPF_CDD                     5413
#define IDS_NOITEMS                     5414
#define IDS_COMPAREX                    5415
#define IDS_MERGEX                      5416
#define IDS_EXPORT_TEXTX                5417
#define IDS_EXPORT_XMLX                 5418
#define IDS_ADVANCED_TITLETEXT          5420
#define IDS_ADVANCED_PASSWORDTEXT       5421
#define IDS_ADVANCED_GROUPTEXT          5422
#define IDS_ADVANCED_USERTEXT           5423
#define IDS_AUTOTYPE                    5424
#define IDS_PWHISTORY                   5425
#define IDS_ORIGINALDB                  5426
#define IDS_COMPARISONDB                5427
#define IDS_COMPARERESULTS              5428
#define IDS_COPYLEFTRIGHT               5429
#define IDS_ADVANCED_SELECTSOME         5430
#define IDS_ADVANCED_SELECTALL          5431
#define IDS_ADVANCED_DESELECTSOME       5432
#define IDS_ADVANCED_DESELECTALL        5433
#define IDS_NOFIELDSFORCOMPARE          5434
#define IDS_ADVANCED                    5435
#define IDS_YES                         5437
#define IDS_NO                          5438
#define IDS_XMLIMPORTFAILED             5440
#define IDS_COPYUNKNOWNFIELDS           5441
#define IDS_FINDX                       5442
#define IDS_NOFIELDSFORSEARCH           5443
#define IDS_NUMCHILD                    5444
#define IDS_NUMCHILDREN                 5445
#define IDS_DELENT                      5446
#define IDS_EXTERNAL_EDITOR_WARNING     5447
#define IDS_NOTES_IN_EXTERNAL_EDITOR    5448
#define IDS_CPF_TVDD                    5449
#define IDS_RECORDUNKNOWNFIELDS         5450
#define IDS_IMPORTFILE                  5451
#define IDS_EXPORTFILE                  5453
#define IDS_DDBASEISALIAS               5464
#define IDS_CLOSE_B4_CHECK              5468
#define IDS_CONFIRM_CLOSE               5469
#define IDS_LATEST_VERSION              5470
#define IDS_CANT_CONTACT_SERVER         5471
#define IDS_UP2DATE                     5472
#define IDS_NEWER_AVAILABLE_SHORT       5473
#define IDS_CANT_READ_VERINFO           5474
#define IDS_TRYING2CONTACT_SERVER       5475
#define IDS_NEWER_CAPTION               5476
#define IDS_NEWER_AVAILABLE             5477
#define IDS_TEXTIMPORTFAILED            5479
#define IDS_COMPARINGDATABASE           5480
#define IDS_COPYENTRY                   5481
#define IDS_CASE_INSENSITIVE            5482
#define IDS_CASE_SENSITIVE              5483
#define IDS_CANTEMAIL                   5484
#define IDS_MENUSENDEMAIL               5486
#define IDS_SELECTREPORT                5487
#define IDS_NOREPORTSEXIST              5488
#define IDS_VISIT_WEBSITE               5489
#define IDS_ICON                        5496
#define IDS_ABASE_MISSING               5497
#define IDS_SBASEINVALID                5500
#define IDS_MUSTHAVETARGET              5501
#define IDS_VIEWSHORTCUTS               5502
#define IDS_MULTIPLETARGETSFOUND        5505
#define IDS_TARGETNOTFOUND              5506
#define IDS_PROVISMUTUALLYEXCL          5507
#define IDS_PWPOLICY                    5508
#define IDS_COMPPWPOLICY                5509
#define IDS_SETPASSWORDPOLICY           5510
#define IDS_DEFAULTPWLENGTHTOOSMALL     5511
#define IDS_CANTSPECIFYMINNUMBER        5512
#define IDS_SAMPLETEXT                  5513
#define IDS_EMPTYSAMPLETEXT             5514
#define IDS_MENUCOPYEMAIL               5516
#define IDS_COPYEMAIL                   5517
#define IDS_SCTARGET                    5520
#define IDS_ADVANCEDOPTIONS             5522
#define IDS_ADVANCEDSUBSET              5523
#define IDS_ADVCASE_INSENSITIVE         5524
#define IDS_ADVCASE_SENSITIVE           5525
#define IDS_ADVANCEDFIELDS              5526
#define IDS_USER                        5528
#define IDS_PSWD                        5529
#define IDS_SHOWTOOLBAR                 5530
#define IDS_HIDETOOLBAR                 5531
#define IDS_REPORTCREATED               5540
#define IDS_FINDGROUP                   5541
#define IDS_FINDTITLE                   5542
#define IDS_FINDUSER                    5543
#define IDS_TEXT                        5544
#define IDS_XML                         5545
#define IDS_VIEWREPORT                  5546
#define IDS_CANCEL                      5547
#define IDS_CONTINUE                    5548
#define IDS_EXIT                        5549
#define IDS_READONLY                    5550
#define IDS_READWRITE                   5551
#define IDS_SEARCH                      5552
#define IDS_NEW                         5553
#define IDS_OVERRIDE_POLICY             5555
#define IDS_PASSWORDEXPIRYDATEINT       5556
#define IDS_NOFIELDSFORFILTER           5557
#define IDS_NUMTOOSMALL                 5558
#define IDS_NUMTOOLARGE                 5559
#define IDS_NUM1NEGATIVE                5560
#define IDS_NUM1NOTLTNUM2               5561
#define IDS_CANTBELESSTHANMIN           5562
#define IDS_CANTBEGREATERTHANMAX        5563
#define IDS_NUM1CANTBEMAX               5564
#define IDS_DATE1NOTB4DATE2             5565
#define IDS_NOSTRING                    5566
#define IDS_FILTERINCOMPLETE            5567
#define IDS_NOFILTERSENABLED            5568
#define IDS_NORULESELECTED              5569
#define IDS_ENTRYTYPE                   5570
#define IDS_FILTERINFO_NONE             5571
#define IDS_FILTERINFO                  5572
#define IDS_HFILTERINFO                 5573
#define IDS_PFILTERINFO                 5574
#define IDS_PRESENT                     5575
#define IDS_HACTIVE                     5576
#define IDS_HNUM                        5577
#define IDS_HMAX                        5578
#define IDS_HDATE                       5579
#define IDS_HPSWD                       5580
#define IDS_PLOWER                      5582
#define IDS_PUPPER                      5583
#define IDS_PDIGITS                     5584
#define IDS_PSYMBOL                     5585
#define IDS_PASSWORDHISTORY             5589
#define IDS_UNKNOWNFIELDSFILTER         5590
#define IDS_FILTERACTIVE                5594
#define IDS_FILTERINACTIVE              5595
#define IDS_FILTERFIELD                 5596
#define IDS_FILTERRULE                  5597
#define IDS_NOITEMSPASSEDFILTERING      5600
#define IDS_NOTDEFINED                  5601
#define IDS_SETDISPLAYFILTERS           5602
#define IDS_SETPWHISTFILTERS            5603
#define IDS_SETPWPOLICYFILTER           5604
#define IDS_SETFILTERS                  5605
#define IDS_CLEARFILTERS                5606
#define IDS_HELP                        5607
#define IDS_OK                          5608
#define IDS_NUMITEMSFILTER              5609
#define IDS_AND_OR                      5610
#define IDS_SELECTFIELD                 5611
#define IDS_CRITERIA_DESC               5612
#define IDS_PICKFIELD                   5613
#define IDS_FLC_TOOLTIP0                5614
#define IDS_FLC_TOOLTIP1                5615
#define IDS_FLC_TOOLTIP2                5616
#define IDS_FLC_TOOLTIP3                5617
#define IDS_FLC_TOOLTIP4                5618
#define IDS_FLC_TOOLTIP5                5619
#define IDS_FLC_TOOLTIP6                5620
#define IDS_FILTERNAMEEMPTY             5621
#define IDS_DELETE                      5622
#define IDS_SELECT                      5623
#define IDS_VIEW                        5624
#define IDS_FILTERSEXPORTEDOK           5625
#define IDS_FILTERSIMPORTEDOK           5626
#define IDS_CANTAUTOIMPORTFILTERS       5630
#define IDS_REPLACEFILTER               5631
#define IDS_FILTEREXISTS                5632
#define IDS_SHOWDRAGBAR                 5633
#define IDS_HIDEDRAGBAR                 5634
#define IDS_CONFIRMFILTERDELETE         5635
#define IDS_DBPOOLNAME                  5636
#define IDS_AUTOLOADPOOLNAME            5637
#define IDS_IMPORTEDPOOLNAME            5638
#define IDS_SESSIONPOOLNAME             5639
#define IDS_FILTERNAME                  5640
#define IDS_FILTERSOURCE                5641
#define IDS_FILTERCOPY2DB               5642
#define IDS_FILTEREXPORT                5643
#define IDS_FILTERAPPLY                 5644
#define IDS_MINIMIZECONFLICT            5645
#define IDS_CLICKTOCOPY                 5646

#define IDS_SUBSETINDEXTOOBIG           5648
#define IDS_MENUCREATESHORTCUT          5649
#define IDS_AREYOUSURE                  5650
#define IDS_EDITEXTERNALLY              5651
#define IDS_WORD_WRAP                   5652
#define IDS_SHOW_NOTES                  5653
#define IDS_RUNCOMMAND                  5654
#define IDS_COMPRUNCOMMAND              5655
#define IDS_TRAYRUNCOMMAND              5656
#define IDS_CANTRUNCOMMAND              5657
#define IDS_CLICKTOCOPYEXPAND           5658
#define IDS_RUNCOMMAND_ERROR            5659
#define IDS_CANTLOAD_AUTOTYPEDLL        5660
#define IDS_RUN_ERRORMSG                5661
#define IDS_RUN_IGNOREORFIX             5662
#define IDS_SEARCHTOP                   5663
#define IDS_SEARCHBOTTOM                5665
#define IDS_TRAYBROWSEPLUS              5666
#define IDS_LAUNCH                      5667
#define IDS_LAUNCHPLUS                  5668
#define IDS_CLICKTOGOPLUS               5669
#define IDS_DELGRP                      5670
#define IDS_GROUPCOPIED                 5671
#define IDS_TITLECOPIED                 5672
#define IDS_USERCOPIED                  5673
#define IDS_PSWDCOPIED                  5674
#define IDS_NOTESCOPIED                 5675
#define IDS_URLCOPIED                   5676
#define IDS_AUTOTYPECOPIED              5677
#define IDS_RUNCMDCOPIED                5678
#define IDS_TRAYBROWSEALT               5679
#define IDS_COL_MENUITEM                5680
#define IDS_COL_SHORTCUT                5681
#define IDS_SHCT_TOOLTIP                5682
#define IDS_SHCT_WARNING1               5684
#define IDS_SHCT_WARNING2               5685
#define IDS_SHCT_WARNING3               5686
#define IDS_CTRLP                       5687
#define IDS_ALTP                        5688
#define IDS_SHIFTP                      5689
#define IDS_OSK_VERSION_MISMATCH        5690
#define IDS_COMPXTIME_INT               5691
#define IDS_TREEFONT                    5692
#define IDS_PSWDFONT                    5693
#define IDS_OSK_NO_UNICODE_FONT         5694
#define IDS_DRAGTOCOPY                  5697
#define IDS_ADDENTRY                    5698
#define IDS_EDITENTRY                   5699
#define IDS_NA                          5700
#define IDS_ISANALIASBASE               5702
#define IDS_ISASHORTCUTBASE             5703
#define IDS_COMPDCA                     5704
#define IDS_DCA                         5705
#define IDS_VKBDFONT                    5709
#define IDS_OSKFONT                     5710
#define IDS_USRFONT                     5711
#define IDS_MD_MSG1                     5712
#define IDS_MD_MSG2                     5713
#define IDS_MD_MSG3                     5714
#define IDS_MD_CAPTION                  5715
#define IDS_CLOSE                       5716
#define IDS_CLICKTOSEND                 5717
#define IDS_EMAILCOPIED                 5718
#define IDS_EMAIL                       5719
#define IDS_COMPEMAIL                   5720
#define IDS_CLICKTOCOPYPLUS1            5721
#define IDS_TRAYSENDEMAIL               5722
#define IDS_TRAYCOPYEMAIL               5723
#define IDS_STOPREASON                  5724
#define IDS_FILTER_NAME                 5725
#define IDS_DATETIMESTRING              5726
#define IDS_ERROR                       5727
#define IDS_ABORT                       5728
#define IDS_RETRY                       5729
#define IDS_IGNORE                      5730
#define IDS_TRYAGAIN                    5731
#define IDS_AREYOUSURE_OPT              5732
#define IDS_NO_ENTRIES_SELECTED         5736
#define IDS_NO_ENTRIES_PROCESSED        5737
#define IDS_DCALONG                     5738
#define IDS_ENTRYSTATUS                 5739
#define IDS_RECORDSUPDATED              5741
#define IDS_FILEWRITEFAILURE            5742
#define IDS_GENERATEPASSWORD            5743
#define IDS_PASSWORDGENERATED1          5744
#define IDS_PASSWORDGENERATED2          5745
#define IDS_SYNCHRONIZEX                5747
#define IDS_NOFIELDSFORSYNCH            5748
#define IDS_SYNCHINGDATABASE            5750
#define IDS_PICKSYNCHRONIZEEFILE        5753
#define IDS_OPEN                        5754
#define IDS_ENDSESSION                  5755
#define IDS_DBNAME                      5756
#define IDS_PASSPHRASE                  5757
#define IDS_DBFORMAT                    5758
#define IDS_NUMGROUPS                   5759
#define IDS_NUMENTRIES                  5760
#define IDS_WHENSAVED                   5761
#define IDS_WHOSAVED                    5762
#define IDS_WHATSAVED                   5763
#define IDS_FILEUUID                    5764
#define IDS_UNKNFLDS                    5765
#define IDS_NORECYCLEBINTITLE           5766
#define IDS_NORECYCLEBINMSG             5767
#define IDS_EBCONTINUE                  5768
#define IDC_EBDELETE                    5769
#define IDC_EBSELECT                    5770
#define IDS_EBEXIT                      5771
#define IDS_EBLISTCTRL                  5772
#define IDS_EBLISTCTRLROW1              5773
#define IDS_EBLISTCTRLROWN              5774
#define IDS_DBHASDUPLICATES             5775
#define IDS_MERGEFAILED                 5776
#define IDS_SYNCHFAILED                 5777
#define IDS_OKWITHERRORS                5778
#define IDS_COMPLETE                    5779
#define IDS_RECORDSRENAMED              5780 
#define IDS_XMLIMPORTRENAMED            5781
#define IDS_XMLIMPORTSKIPPED            5782
#define IDS_XMLIMPORTPWHERRORS          5783
#define IDS_RECORDSPWHERRRORS           5784
#define IDS_TITLESKIPPED                5785
#define IDS_TITLERENAMED                5786
#define IDS_TITLEPWHERRORS              5787
#define IDS_SAVEBEFOREPROCESS           5788
#define IDS_CHOOSEDATABASEV             5791
#define IDS_TRUNCATETEXT                5792
#define IDS_WARNINGTEXTLENGTH           5793
#define IDS_ENTRYSIZE                   5794
#define IDS_NOIBACKUP2                  5796
#define IDS_SAVEAS                      5797
#define IDS_INVALIDFUTUREDATE           5798
#define IDS_REGISTRY                    5799
#define IDS_MISSINGPASSKEY              5800
#define IDS_PROTECTED                   5801
#define IDS_UNPROTECT                   5802
#define IDS_WZSLCT_WARNING_SYNC         5803
#define IDS_WZSLCT_WARNING_EXP          5804
#define IDS_EXPORT_TEXTX_SINGLE         5807
#define IDS_EXPORT_XMLX_SINGLE          5808
#define IDS_WZDATABASE                  5809
#define IDS_WZFILE                      5810
#define IDS_WZUSINGDB                   5811
#define IDS_WZEXPORTFILE                5812
#define IDS_WZNEXT                      5813
#define IDS_WSSLCT_ALL                  5814
#define IDS_WSSLCT_ENTRY                5815
#define IDS_EXPORTED                    5816
#define IDS_SYNCHRONIZED                5817
#define IDS_WZCOMPAREDB                 5818
#define IDS_WZSYNCHRONIZEDB             5819
#define IDS_WZMERGEDB                   5820
#define IDS_EXPIREDPSWDSEXIST           5821
#define IDS_EXPIREDPSWDSTITLE           5822
#define IDS_EXP_NORMAL                  5823
#define IDS_EXP_NORMAL_WARN             5824
#define IDS_EXP_NORMAL_EXP              5825
#define IDS_EXP_ABASE                   5826
#define IDS_EXP_ABASE_WARN              5827
#define IDS_EXP_ABASE_EXP               5828
#define IDS_EXP_SBASE                   5829
#define IDS_EXP_SBASE_WARN              5830
#define IDS_EXP_SBASE_EXP               5831
#define IDS_WZEXPORTTEXT                5833
#define IDS_WZEXPORTXML                 5834
#define IDS_WZCOMPARE                   5835
#define IDS_WZMERGE                     5836
#define IDS_WZSYNCH                     5837
#define IDS_NONE_EXPORTED               5838
#define IDS_NONE_COMPARED               5839
#define IDS_NONE_SYNCHRONIZED           5840
#define IDS_DEFAULTAUTOTYPE             5841
#define IDS_SYMBOLS                     5842
#define IDS_COMPSYMBOLS                 5843
#define IDS_PROTECTEDENTRY              5844
#define IDS_CHANGE_READWRITE            5845
#define IDS_CHANGE_READONLY             5846
#define IDS_BACKOUT_CHANGES             5847
#define IDS_CHANGEMODE                  5848
#define IDS_CHANGEMODE_FAILED           5849
#define IDS_CM_FAIL_REASON1             5850
#define IDS_CM_FAIL_REASON2             5851
#define IDS_CM_FAIL_REASON3             5852
#define IDS_CM_FAIL_REASON4             5853
#define IDS_CM_FAIL_REASON5             5854
#define IDS_SB_TT_DBCLICK               5855
#define IDS_SB_TT_CBACTION              5856
#define IDS_SB_TT_CONFIG                5857
#define IDS_SB_TT_MODIFIED              5858
#define IDS_SB_TT_MODE                  5859
#define IDS_SB_TT_NUMENTRIES            5860
#define IDS_SB_TT_FILTER                5861
#define IDS_DRAGTOAUTOTYPE              5862
#define IDS_REPLACEEXPORTFILE           5863
#define IDS_COMPPROTECTED               5864
#define IDS_WZACTIONFAILED              5865
#define IDS_CANNOTCREATEDIR             5866
#define IDS_WITHWARNINGS                5867
#define IDS_IMPORTFAILED                5870
#define IDS_PASSWORDLEN                 5871
#define IDS_SHIFTDCA                    5872
#define IDS_SHIFTDCALONG                5873
#define IDS_COMPSHIFTDCA                5874
#define IDS_ENTER_NEW_DB_NAME           5875
#define IDS_ENTER_NEW_DB_DESCRIPTION    5876
#define IDS_INPUTBOX_CHAR_COUNT         5877
#define IDS_NUMGROUPS_E                 5878
#define IDS_POLICYNAME                  5879
#define IDS_NEWPOLICY                   5880
#define IDS_EDITPOLICY                  5881
#define IDS_DELETEPOLICY                5882
#define IDS_LISTPOLICY                  5883
#define IDS_UNDOPOLICY                  5884
#define IDS_REDOPOLICY                  5885
#define IDS_CANCELPOLICYCHANGES         5886
#define IDS_SAVEPOLICYCHANGES           5887
#define IDS_USECOUNT                    5888
#define IDS_PSWDPOLICY                  5889
#define IDS_POLICYFIELD                 5890
#define IDS_VALUE                       5891
#define IDS_AREYOUSURE_PN               5894
#define IDS_INVALIDPOLICYNAME1          5895
#define IDS_INVALIDPOLICYNAME2          5896
#define IDS_XMLIMPORTWITHWARNINGS       5905
#define IDS_CHANGED_POLICIES            5906
#define IDS_NOT_USED                    5908
#define IDS_COMPPOLICYNAME              5909
#define IDS_POLICY_VIEWENTRY            5910
#define IDC_DETAILS                     5911
#define IDS_LIST                        5912
#define IDS_EDIT_DEFAULT_POLICY         5913
#define IDS_ADD_NAMED_POLICY            5914
#define IDS_EDIT_NAMED_POLICY           5915
#define IDS_TESTPOLICY                  5916
#define IDS_CLICKTOCOPYGENPSWD          5917
#define IDS_PR_MUSTHAVECHARACTERS       5918
#define IDS_OWNSYMBOLSMISSING           5919
#define IDS_ENTRIESCLEARALL             5920
#define IDS_NOTESZOOMIN                 5921
#define IDS_NOTESZOOMOUT                5922
#define IDS_VALIDATE_ISSUES             5923
#define IDS_CURRENT_ENTRY               5924
#define IDS_COMPARISON_ENTRY            5925
#define IDS_PWHACTIVE                   5926
#define IDS_PWHMAX                      5927
#define IDS_PWHNUM                      5928
#define IDS_PWHENTRY                    5929
#define IDS_COPYALL                     5930
#define IDS_SYNCHRONIZEALL              5931
#define IDS_SYNCENTRY                   5932
#define IDS_OPERATION_ABORTED           5933
#define IDS_FORMAT_CMP_POLICY           5934
#define IDS_EXPORTENTMENU               5935
#define IDS_EXPORTENT2PLAINTEXT         5936
#define IDS_EXPORTENT2XML               5937
#define IDS_HELP_UNAVALIABLE            5938
#define IDS_SUBSETINDEXTOOSMALL         5939
#define IDS_KBSHORTCUT                  5940
#define IDS_COMPKBSHORTCUT              5941
#define IDS_KBS_INVALID                 5942
#define IDS_KBS_ADD_ALT                 5943
#define IDS_KBS_ADD_ALTSHIFT            5944
#define IDS_KBS_ADD_CTRL                5945
#define IDS_KBS_ADD_CTRLSHIFT           5946
#define IDS_KBS_ADD_ALTCTRL             5947
#define IDS_KBS_ADD_ALTCTRLSHIFT        5948
#define IDS_KBS_CANTADD                 5949
#define IDS_KBS_INUSEBYENTRY            5950
#define IDS_KBS_INUSEBYMENU             5951
#define IDS_KBS_TOOLTIP0                5952
#define IDS_KBS_TOOLTIP1                5953
#define IDS_KBS_SAMEASAPP               5954
#define IDS_APPHOTKEY_OVERRIDE          5955
#define IDS_ENTRYKBST_OVERRIDE          5956
#define IDS_EMPTY_DB                    5957
#define IDS_TOOMANYTRIES                5958
#define IDS_EXPORTENT2DB                5959
#define IDS_EXPORTGRPMENU               5960
#define IDS_NAMEDBFILE                  5961
#define IDS_WZEXPORTDB                  5962
#define IDS_EXPORT_TEXTX_GROUP          5963
#define IDS_EXPORT_XMLX_GROUP           5964
#define IDS_WSSLCT_GROUP                5966
#define IDS_EXDB                        5967
#define IDS_EXPORTWARNING               5970
#define IDS_NOTESFONT                   5971
#define IDS_CANT_FIND_EXT_EDITOR        5972
#define IDS_APP_DEFAULT                 5973
#define IDS_ALL_IMAGE_FILES             5974
#define IDS_NOPREVIEW_AVAILABLE         5975
#define IDS_ATTACHMENT_NOTFOUND         5976
#define IDS_MENUITEM_EXPORT2V3FORMAT    5977
#define IDS_MENUITEM_EXPORT2V4FORMAT    5978
#define IDS_ATTREF                      5979
#define IDS_COMPATTREF                  5980
#define IDS_FILETITLE                   5981
#define IDS_FILENAME                    5982
#define IDS_FILEPATH                    5983
#define IDS_FILEMEDIATYPE               5984
#define IDS_NUMATTACHMENTS              5985
#define IDS_ATTACHMENTS                 5986
#define IDS_CTIME                       5987
#define IDS_FILECTIME                   5988
#define IDS_FILEMTIME                   5989
#define IDS_FILEATIME                   5990
#define IDS_SETATTACHMENTFILTER         5991
#define IDS_AFILTERINFO                 5992
#define IDS_NOMEDIATYPE                 5993
#define IDS_CLICKTOLISTENTRIES          5994
#define IDS_NUMEMPTYGROUPS              5995
#define IDS_ADDEDITFONT                 5996
#define IDS_SHORTCUT_WARNING            5997
#define IDS_NOIBACKUP3                  5998

#define IDS_YUBI_CLICK_PROMPT           6000
#define IDS_YUBI_INSERT_PROMPT          6001
#define IDS_YUBI_TIMEOUT                6002
#define IDS_YUBI_UNINITIALIZED          6003
#define IDS_YUBI_INIT_FAILED            6004
#define IDS_YUBI_INIT_SUCCESS           6005
#define IDS_YUBI_SET_FAILED             6006
#define IDS_YUBI_SET_SUCCESS            6007
#define IDS_YUBI_SET_DB_SAVE_FAILED     6008
#define IDS_YUBI_READ_FAIL              6009

#define IDS_STATIC_DB_PREFS_RO_WARNING  6020
#define IDS_DB_READ_ONLY                6021
#define IDS_NO_DB                       6022
#define IDS_SAVEDRESTOREDDB             6023
#define IDS_UNSAVEDRESTOREDDB           6024
#define IDS_VIEWATTACHMENT              6025
#define IDS_IMAGE_SAVE_FAILED           6026
#define IDS_IMAGE_LOAD_FAILED           6027
#define IDS_IMAGE_LIMIT_1               6028
#define IDS_IMAGE_IMPORT_FAILED         6029
#define IDS_MEM_ALLOC_FAILED            6030
#define IDS_MEM_LOCK_FAILED             6031
#define IDS_CLEARMRU                    6032
#define IDS_CONFIRMCLEARMRU             6033
#define IDS_EXPANDPATH                  6035
#define IDS_CANT_EXPANDPATH             6036
#define IDS_PWHISTORYCOPIED             6037
#define IDS_OLDPSWDCOPIED               6038
#define IDS_CHANGINGBASEENTRY           6039
#define IDS_CHANGINGBASEENTRY1          6040
#define IDS_CHANGINGBASEENTRY2          6041
#define IDS_EXP_ALIAS                   6042
#define IDS_HOSTUSER                    6043
#define IDS_LIST_OF_ALIASES             6044
#define IDS_LIST_OF_SHORTCUTS           6045
#define IDS_EXT_EDITOR_ACTIVE           6046
#define IDS_CANCEL_EXT_EDITOR           6047
#define IDS_PASSWORDCOPIED              6048
#define IDS_COPYPASSWORDHELP1           6049
#define IDS_COPYPASSWORDHELP2           6050
#define IDS_WSSLCT_FILTERED             6051
#define IDS_GOTOSHORTCUTS               6052
#define IDS_VIEWBASEENTRY               6053
#define IDS_DBIDINUSE                   6054
#define IDS_INCLUDEDBASES               6055
#define IDS_GC_ONE_CHILD                6060
#define IDS_GC_N_CHILDREN               6061
#define IDS_USEANYWAY                   6062
#define IDS_DISCARD                     6063
#define IDS_SAVE                        6064

#define IDS_SCRCAP_TT_STATE_ERROR                           6067
#define IDS_SCRCAP_TT_DISALLOWED_DEFAULT                    6068
#define IDS_SCRCAP_TT_ALLOWED_DBPREF                        6069

#define IDS_SCRCAP_TT_OVERRIDE_INVALID                      6070
#define IDS_SCRCAP_TT_OVERRIDE_NONE                         6071
#define IDS_SCRCAP_TT_OVERRIDE_CMDLINE                      6072
#define IDS_SCRCAP_TT_OVERRIDE_REGISTRY                     6073

#define IDS_SCRCAP_EXCLUDE_OVERRIDE_WARNING_BEFORE_INVALID  6080
#define IDS_SCRCAP_EXCLUDE_OVERRIDE_WARNING_BEFORE_NONE     6081
#define IDS_SCRCAP_EXCLUDE_OVERRIDE_WARNING_BEFORE_CMDLINE  6082
#define IDS_SCRCAP_EXCLUDE_OVERRIDE_WARNING_BEFORE_REGISTRY 6083

#define IDS_SCRCAP_EXCLUDE_OVERRIDE_WARNING_AFTER_INVALID   6090
#define IDS_SCRCAP_EXCLUDE_OVERRIDE_WARNING_AFTER_NONE      6091
#define IDS_SCRCAP_EXCLUDE_OVERRIDE_WARNING_AFTER_CMDLINE   6092
#define IDS_SCRCAP_EXCLUDE_OVERRIDE_WARNING_AFTER_REGISTRY  6093

#define IDS_ADDEDITERR_INVALID_TOTP_KEY                     6100
#define IDS_TWOFACTORKEY                                    6101
#define IDS_TWOFACTORCODEBUTTON_CONFIGURED                  6102
#define IDS_TWOFACTORCODEBUTTON_NOTCONFIGURED               6103
#define IDS_TWOFACTORCODESTATIC_CONFIGURED                  6104
#define IDS_TWOFACTORCODE_COPIED                            6105
#define IDS_TWOFACTORCODE_ERROR_TITLE                       6106
#define IDS_TWOFACTORCODE_ERROR_MESSAGE                     6107
#define IDS_TWOFACTORCODE_ERROR_KEYEMPTY                    6108
#define IDS_AC_STATIC_TWOFACTORCODE                         6115
#define IDS_DISPLAYAUTHCODE_TITLEFMT                        6116
